### Installation
The module, Dupamb requires pandas module to function
This module is used to remove the tuples having duplicate and ambiguous tuples in a dataset. The first column of the csv file should be that of the target class or feature while the others be independent features affecting target feature.

Usages: python-dupamb <InputDataFile> 
	
```sh
$ pip install python-dupamb
$ python-dupamb myData.csv
```
### License
MIT
### Author
Sahil Ahuja
